.. i21y documentation master file, created by
   sphinx-quickstart on Sun Feb 12 10:42:06 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to i21y's documentation!
================================
i21y (a.k.a internationalization.py) is a library for i18n support in Python.

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   usage
   i21y

.. toctree::
   :maxdepth: 1
   :caption: Links:

   GitHub <https://github.com/tasuren/i21y/>
   PyPi <https://pypi.org/project/i21y/>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`